﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Data;
using Telerik.Web.UI;
using System.Drawing;

public partial class _524663RadDockLayout : System.Web.UI.Page
{

    private DataTable PulsarLayout;
    private enum Levels
    {
        Home,
        Section,
        Branch,
        Message,
        Slide
    }

    private void AddSection()
    {
        DataTable PulsarLayout = (DataTable)HttpContext.Current.Session["PulsarLayout"];

        //Empty Section Record
        PulsarLayout.Rows.Add(new string[] { null, Levels.Section.ToString(), "Empty", "1" });

        //Empty Branch Record
        PulsarLayout.Rows.Add(new string[] { null, Levels.Branch.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

        //Empty Message Record
        PulsarLayout.Rows.Add(new string[] { null, Levels.Message.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

        //Empty Slide Record
        PulsarLayout.Rows.Add(new string[] { null, Levels.Slide.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

        HttpContext.Current.Session["PulsarLayout"] = PulsarLayout;
    }

    protected override void OnInit(EventArgs e)
    {
        //added to prevent incorrect reorder (e.g if it is navigated to another page and returns with back button - IE issue)
        Response.Cache.SetCacheability(HttpCacheability.NoCache);
        base.OnInit(e);
        BindOrgChart();
    }
    protected void BindOrgChart()
    {
        if (Page != null && IsPostBack)
        {
            if (!string.IsNullOrEmpty(Page.Request.Form["addSectionIndicator"]))
                AddSection();
        }

        if (!IsPostBack)
        {
            PulsarLayout = new DataTable();

            DataColumn column = new DataColumn();
            column.DataType = System.Type.GetType("System.Int32");
            column.ColumnName = "PulsarLayoutID";
            column.AutoIncrement = true;
            column.AutoIncrementSeed = 1;
            column.AutoIncrementStep = 1;
            PulsarLayout.Columns.Add(column);
            PulsarLayout.Columns.Add("Level");
            PulsarLayout.Columns.Add("Name");
            PulsarLayout.Columns.Add("ParentID", System.Type.GetType("System.Int32"));

            //Empty Home Record
            PulsarLayout.Rows.Add(new string[] { "1", null, "Home", null });


            //Empty Section Record
            PulsarLayout.Rows.Add(new string[] { "2", Levels.Section.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

            //Empty Branch Record
            PulsarLayout.Rows.Add(new string[] { "3", Levels.Branch.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

            //Empty Message Record
            PulsarLayout.Rows.Add(new string[] { "4", Levels.Message.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

            //Empty Slide Record
            PulsarLayout.Rows.Add(new string[] { "5", Levels.Slide.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

            Session["PulsarLayout"] = PulsarLayout;
        }


        PulsarChart.GroupEnabledBinding.NodeBindingSettings.DataFieldID = "PulsarLayoutID";
        PulsarChart.GroupEnabledBinding.NodeBindingSettings.DataFieldParentID = "ParentID";
        PulsarChart.RenderedFields.NodeFields.Add(new Telerik.Web.UI.OrgChartRenderedField() { DataField = "Level" });
        PulsarChart.GroupEnabledBinding.NodeBindingSettings.DataSource = Session["PulsarLayout"];
        PulsarChart.DataBind();

        if (!IsPostBack)
        {
            for (int i = 0; i < 5; i++)
            {
                RadDock _Newdock = CreateRadDock(i.ToString(), new string[] { "ZoneHome", "ZoneBranch", "ZoneSlide", "ZoneGeneralSlides" });
                ZoneGeneralSlides.Controls.Add(_Newdock);
            }
        }

    }
    int GetLastRowID(DataTable _DataTable)
    {
        return Convert.ToInt32(_DataTable.Rows[_DataTable.Rows.Count - 1][0]);
    }
    protected void Page_Init(object sender, EventArgs e)
    {

        if (!IsPostBack)
        {
            if (Session["CurrentDockStatesDynamicDocks"] != null)
            {
                ((List<DockState>)Session["CurrentDockStatesDynamicDocks"]).Clear();
            }

        }

        //Recreate the docks in order to ensure their proper operation
        for (int i = 0; i < CurrentDockStates.Count; i++)
        {
            RadDock dock = CreateRadDockFromState(CurrentDockStates[i]);
            //We will just add the RadDock control to the RadDockLayout.
            // You could use any other control for that purpose, just ensure
            // that it is inside the RadDockLayout control.
            // The RadDockLayout control will automatically move the RadDock
            // controls to their corresponding zone in the LoadDockLayout
            // event (see below).

            RadDockLayout1.Controls.Add(dock);
            //We want to save the dock state every time a dock is moved.
            CreateSaveStateTrigger(dock);
        }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        if (!IsPostBack)
        {
            //avoiding sharing Session variables between tabs in one browser
            SessionID.Value = Guid.NewGuid().ToString();
        }
        else
        {
            int Count = ((RadDockZone)PulsarChart.Nodes[0].GroupItems[0].FindControl("ZoneHome")).Docks.Count;

            if (Count == 1)
            {
                string HomeID = ((RadDockZone)PulsarChart.Nodes[0].GroupItems[0].FindControl("ZoneHome")).Docks[0].ID;
                ((RadDockZone)PulsarChart.Nodes[0].GroupItems[0].FindControl("ZoneHome")).AllowedDocks = new string[] { HomeID };
            }
            else
            {
                ((RadDockZone)PulsarChart.Nodes[0].GroupItems[0].FindControl("ZoneHome")).AllowedDocks = new string[] { };
            }
        }
    }

    private RadDock CreateRadDock(string ID, string[] Zones)
    {
        RadDock dock = new RadDock();
        dock.DockMode = DockMode.Docked;
        dock.UniqueName = ID + "_" + Guid.NewGuid().ToString().Replace("-", "a");
        dock.ID = dock.UniqueName;
        dock.EnableDrag = true;
        dock.AllowedZones = Zones;
        dock.AutoPostBack = true;
        dock.Title = ID;
        dock.DockHandle = DockHandle.TitleBar;
        dock.EnableRoundedCorners = true;
        dock.DefaultCommands = Telerik.Web.UI.Dock.DefaultCommands.None;
        dock.Style["Padding"] = "5px 0px 0px 0px;";
        return dock;
    }
    protected void dock_DockPositionChanged(object sender, DockPositionChangedEventArgs e)
    {

    }
    
    protected void PulsarChart_NodeDataBound(object sender, OrgChartNodeDataBoundEventArguments e)
    {
        //var zone = e.Node.GroupItems[0].FindControl("TemplatedZone") as RadDockZone;
        if (e.Node.Level == 0)
        {
            // If Home Node? Will create new DockZone to contain the Slide Dock.
            OrgChartGroupItem _GroupItem = new OrgChartGroupItem() { Template = new RadZoneTemplate() { ZoneName = "Home", ZoneID = "ZoneHome" } };
            e.Node.GroupItems.Add(_GroupItem);




        }
        else if (e.Node.Level == 1)
        {
            // If Section Node? Will create new DockZone to contain the Slide Dock.
            OrgChartGroupItem _GroupItem = new OrgChartGroupItem() { Template = new SectionTemplate() { ZoneName = "Branch(s)" } };
            e.Node.GroupItems.Add(_GroupItem);

        }
        else if (e.Node.Level == 2)
        {
            // If Branch Node? Will create new DockZone to contain the Slide Dock.
            OrgChartGroupItem _GroupItem = new OrgChartGroupItem() { Template = new RadZoneTemplate() { ZoneName = "Branch(s)", ZoneID = "ZoneBranch" } };
            e.Node.GroupItems.Add(_GroupItem);
        }
        else if (e.Node.Level == 3)
        {

        }
        else if (e.Node.Level >= 4)
        {
            // If Slide Node? Will create new DockZone to contain the Slide Dock.
            OrgChartGroupItem _GroupItem = new OrgChartGroupItem() { Template = new RadZoneTemplate() { ZoneName = "Slide(s)", ZoneID = "ZoneSlide" } };
            e.Node.GroupItems.Add(_GroupItem);
            // _GroupItem.OrgChart.GroupColumnCount = PulsarChart.Nodes[PulsarChart.Nodes.Count].Level;
        }
    }
    #region RadZoneTemplate

    class RadZoneTemplate : ITemplate
    {
        string _ZoneName;

        public string ZoneName
        {
            get { return _ZoneName; }
            set { _ZoneName = value; }
        }

        string _ZoneID;

        public string ZoneID
        {
            get { return _ZoneID; }
            set { _ZoneID = value; }
        }

        public void InstantiateIn(Control container)
        {

            RadDockZone Zone = new RadDockZone();
            Zone.UniqueName = ZoneID;
            Zone.ID = ZoneID;
            Zone.FitDocks = true;
            Zone.BorderStyle = BorderStyle.None;
            Zone.Style["Width"] = "100%;";
            Zone.Style["Height"] = "100%;";
            Zone.Style["padding"] = "0px 0px 0px 0px;";
            Zone.Style["margin"] = "0px 0px 0px 0px;";
            Zone.BackColor = Color.Aqua;
            container.Controls.Add(Zone);
        }

        private void label1_DataBinding(object sender, EventArgs e)
        {


        }
    }

    #endregion

    #region RadTitleBarTemplate

    class RadTitleBarTemplate : ITemplate
    {
        string _ZoneName;

        public string ZoneName
        {
            get { return _ZoneName; }
            set { _ZoneName = value; }
        }
        public void InstantiateIn(Control container)
        {
            PlaceHolder _ph = new PlaceHolder();
            _ph.Controls.Add(new LiteralControl("<table align=\"right\">"));
            _ph.Controls.Add(new LiteralControl("<tr>"));
            _ph.Controls.Add(new LiteralControl("<td>"));
            _ph.Controls.Add(new LiteralControl("test"));
            _ph.Controls.Add(new LiteralControl("</td>"));
            _ph.Controls.Add(new LiteralControl("</tr>"));
            _ph.Controls.Add(new LiteralControl("</table>"));
            container.Controls.Add(_ph);
        }

        private void label1_DataBinding(object sender, EventArgs e)
        {
        }
    }

    #endregion

    #region RadTitleBarTemplate

    class SectionTemplate : ITemplate
    {
        string _ZoneName;

        public string ZoneName
        {
            get { return _ZoneName; }
            set { _ZoneName = value; }
        }
        public void InstantiateIn(Control container)
        {
            PlaceHolder _ph = new PlaceHolder();
            _ph.Controls.Add(new LiteralControl("<table style=\"height:100%; width:100%; vertical-align:top; background-color:Black;\" cellpadding=\"0\" cellspacing=\"0\" border=\"0\" background-color: \"green\" align=\"right\">"));
            _ph.Controls.Add(new LiteralControl("<tr>"));
            _ph.Controls.Add(new LiteralControl("<td valign=\"top\" align=\"right\">"));
            //Button _AddSection = new Button();
            //_AddSection.ID = "btnAddSection";
            //_AddSection.Text = "Add Section";

            RadButton _AddSection = new RadButton();
            _AddSection.ID = "btnAddSection";
            _AddSection.Text = "Add Section";
            _AddSection.AutoPostBack = false;
            _AddSection.UseSubmitBehavior = false;
            _AddSection.OnClientClicked = "addSection";

            //_AddSection.Click += new EventHandler(btnAddSection_Click);
            _ph.Controls.Add(_AddSection);
            _ph.Controls.Add(new LiteralControl("</td>"));
            _ph.Controls.Add(new LiteralControl("</tr>"));
            _ph.Controls.Add(new LiteralControl("</table>"));
            container.Controls.Add(_ph);
        }

        //private void btnAddSection_Click(object sender, EventArgs e)
        //{

        //    Button _btn = (Button)sender;

        //    RadOrgChart _PulsarChart = (RadOrgChart)_btn.NamingContainer.Page.FindControl("PulsarChart");

        //    //DataTable PulsarLayout = (DataTable)HttpContext.Current.Session["PulsarLayout"];

        //    ////Empty Section Record
        //    //PulsarLayout.Rows.Add(new string[] { null, Levels.Section.ToString(), "Empty", "1" });

        //    ////Empty Branch Record
        //    //PulsarLayout.Rows.Add(new string[] { null, Levels.Branch.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

        //    ////Empty Message Record
        //    //PulsarLayout.Rows.Add(new string[] { null, Levels.Message.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

        //    ////Empty Slide Record
        //    //PulsarLayout.Rows.Add(new string[] { null, Levels.Slide.ToString(), "Empty", GetLastRowID(PulsarLayout).ToString() });

        //    //HttpContext.Current.Session["PulsarLayout"] = PulsarLayout;

        //    _PulsarChart.DataBind();
        //}

        int GetLastRowID(DataTable _DataTable)
        {
            return Convert.ToInt32(_DataTable.Rows[_DataTable.Rows.Count - 1][0]);
        }
    }

    #endregion

    protected void PulsarChart_GroupItemDrop(object sender, OrgChartGroupItemDropEventArguments e)
    {


    }
    protected void PulsarChart_NodeDrop(object sender, OrgChartNodeDropEventArguments e)
    {


    }

    protected void btnSave_Click(object sender, EventArgs e)
    {


    }
    #region Save Dock State

    private List<DockState> CurrentDockStates
    {
        get
        {
            //Store the info about the added docks in the session. For real life
            // applications we recommend using database or other storage medium
            // for persisting this information.
            List<DockState> _currentDockStates = (List<DockState>)Session["CurrentDockStatesDynamicDocks"];
            if (Object.Equals(_currentDockStates, null))
            {
                _currentDockStates = new List<DockState>();
                Session["CurrentDockStatesDynamicDocks"] = _currentDockStates;
            }
            return _currentDockStates;
        }
        set
        {
            Session["CurrentDockStatesDynamicDocks"] = value;
        }
    }



    private RadDock CreateRadDockFromState(DockState state)
    {
        RadDock dock = new RadDock();
        dock.ApplyState(state);
        dock.DockMode = DockMode.Docked;
        dock.AutoPostBack = true;
        dock.Width = Unit.Pixel(300);
        dock.ID = state.UniqueName;
        dock.DefaultCommands = Telerik.Web.UI.Dock.DefaultCommands.None;
        dock.DockHandle = DockHandle.TitleBar;
        return dock;
    }

    private void CreateSaveStateTrigger(RadDock dock)
    {
        //Ensure that the RadDock control will initiate postback
        // when its position changes on the client or any of the commands is clicked.
        //Using the trigger we will "ajaxify" that postback.
        dock.AutoPostBack = true;
        dock.CommandsAutoPostBack = true;
    }
    protected void RadDockLayout1_LoadDockLayout(object sender, DockLayoutEventArgs e)
    {
        //Populate the event args with the state information. The RadDockLayout control
        // will automatically move the docks according that information.
        foreach (DockState state in CurrentDockStates)
        {
            e.Positions[state.UniqueName] = state.DockZoneID;
            e.Indices[state.UniqueName] = state.Index;
        }
    }

    protected void RadDockLayout1_SaveDockLayout(object sender, DockLayoutEventArgs e)
    {
        //Save the dock state in the page Session. This will enable us
        // to recreate the dock in the next Page_Init.
        CurrentDockStates = RadDockLayout1.GetRegisteredDocksState();
    }
    #endregion



    protected void PulsarChart_DataBound(object sender, EventArgs e)
    {

    }
    protected void PulsarChart_GroupItemDataBound(object sender, OrgChartGroupItemDataBoundEventArguments e)
    {


    }
    protected void PulsarChart_DataBinding(object sender, EventArgs e)
    {

    }
    protected void btnSave_Click1(object sender, EventArgs e)
    {
        string dd = ((RadDockZone)PulsarChart.Nodes[0].GroupItems[0].FindControl("ZoneHome")).Docks[0].ID.ToString();
    }
    protected void PulsarChart_DataBound1(object sender, EventArgs e)
    {
    }


}